=== modified file '__init__.py'
--- __init__.py	2006-06-19 16:25:43 +0000
+++ __init__.py	2006-06-21 16:07:11 +0000
@@ -144,11 +144,12 @@
         Option("all", help="show annotations on all lines"),
         Option("plain", help="don't highlight annotation lines"),
         Option("line", type=int, argname="lineno",
-               help="jump to specified line number")
+               help="jump to specified line number"),
+        "revision",
     ]
     aliases = ["gblame", "gpraise"]
     
-    def run(self, filename, all=False, plain=False, line='1'):
+    def run(self, filename, all=False, plain=False, line='1', revision=None):
         import pygtk
         pygtk.require("2.0")
 
@@ -174,6 +175,12 @@
 
         if file_id is None:
             raise NotVersionedError(filename)
+        if revision is not None:
+            if len(revision) != 1:
+                raise BzrCommandError("Only 1 revion may be specified.")
+            revision_id = revision[0].in_history(branch).rev_id
+        else:
+            revision_id = None
 
         window = GAnnotateWindow(all, plain)
         window.connect("destroy", lambda w: gtk.main_quit())
@@ -182,7 +189,7 @@
         window.show()
         branch.lock_read()
         try:
-            window.annotate(branch, file_id)
+            window.annotate(branch, file_id, revision_id)
         finally:
             branch.unlock()
         window.jump_to_line(line)

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2006-06-19 23:12:15 +0000
+++ annotate/gannotate.py	2006-06-21 16:07:11 +0000
@@ -57,11 +57,12 @@
         if self.plain:
             self.span_selector.hide()
 
-    def annotate(self, branch, file_id):
+    def annotate(self, branch, file_id, revision_id=None):
         self.revisions = {}
         self.annotations = []
         self.branch = branch
         self.file_id = file_id
+        self.revision_id = revision_id
         
         # [revision id, line number, committer, revno, highlight color, line]
         self.annomodel = gtk.ListStore(gobject.TYPE_STRING,
@@ -76,7 +77,7 @@
             branch.lock_read()
             branch.repository.lock_read()
             for line_no, (revision, revno, line)\
-                    in enumerate(self._annotate(branch, file_id)):
+                    in enumerate(self._annotate(branch, file_id, revision_id)):
                 if revision.revision_id == last_seen and not self.all:
                     revno = committer = ""
                 else:
@@ -120,16 +121,18 @@
         self.annoview.set_cursor(row)
         self.annoview.scroll_to_cell(row, use_align=True)
 
-    def _annotate(self, branch, file_id):
+    def _annotate(self, branch, file_id, revision_id):
         rev_hist = branch.revision_history()
         repository = branch.repository
-        rev_tree = repository.revision_tree(branch.last_revision())
-        rev_id = rev_tree.inventory[file_id].revision
+        if revision_id is None:
+            revision_id = branch.last_revision()
+        rev_tree = repository.revision_tree(revision_id)
+        revision_id = rev_tree.inventory[file_id].revision
         weave = repository.weave_store.get_weave(file_id,
                                                  branch.get_transaction())
         
         revision_cache = RevisionCache(repository)
-        for origin, text in weave.annotate_iter(rev_id):
+        for origin, text in weave.annotate_iter(revision_id):
             rev_id = origin
             try:
                 revision = revision_cache.get_revision(rev_id)

